##  Key Capabilities of SAP LeanIX Architecture and Road Map Planning
SAP LeanIX Architecture and Road Map Planning enriches SAP LeanIX with the following key capabilities and features:
  * Pre-defined Transformation templates: Transformation templates allow you to model changes in your application portfolio in a standardized way to improve the efficiency of IT transformation planning.
![Pre-defined Transformation templates](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e635d7a441014a344cfc27327ee3c_LowRes.png)
Pre-defined Transformation templates
  * Roadmap with Milestones: The Project Roadmaps are enriched with Milestones, to visualize and understand major milestones of your initiatives, keep track of your modernization plans, and ensure IT transformation is on time, scope, and budget. Milestones are used to indicate when certain things are happening and provide structure to your project timeline. Milestones can be linked to lifecycle and thereby model dependencies between different projects and child projects.
![Project Roadmap Report with Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274809317a441014be16b4350ddcc052_LowRes.png)
Project Roadmap Report with Milestones
  * Reports enriched with Impacts: Impacts allow you to see the effects of future changes on a detailed level and understand dependencies between people, data, and infrastructure.
![Impact View in Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27565b9b7a441014964a95d30ab6cfe7_LowRes.png)
Impact View in Reports
  * Timeline Projections: Reports with timelines are enriched with Project/Initiative projections. It helps you compare and understand.
![Time Slider Projection](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c8bde7a441014bac7fa247fdcbc53_LowRes.png)
Time Slider Projection
  * Transformations Explorer: The Transformations Explorer gives a comprehensive overview of all Transformations of the workspace. It allows you to search by name, apply sorting and filtering, make edits, delete, and execute Transformations - all in one centralized location.
![Transformation Explorer](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274224717a44101484cc88e7eff6b09d_LowRes.png)
Transformation Explorer
